@@ -3,7 +3,7 @@ package CPANPLUS::Dist::Slackware::PackageDescription;
 use strict;
 use warnings;
 
-our $VERSION = '1.027';
+our $VERSION = '1.028';
 
 use English qw( -no_match_vars );
 
@@ -12,8 +12,6 @@ use CPANPLUS::Dist::Slackware::Util qw(catdir catfile tmpdir);
 use Config;
 use File::Temp qw();
 use Module::CoreList qw();
-use Pod::Find qw();
-use Pod::Simple::PullParser qw();
 use POSIX qw();
 use Text::Wrap qw($columns);
 use version 0.77 qw();
@@ -228,6 +226,11 @@ sub _summary_from_pod {
     my $module  = $self->module;
     my $srcname = $module->module;
 
+    eval {
+        require Pod::Find;
+        require Pod::Simple::PullParser;
+    } or return;
+
     my $wrksrc = $module->status->extract;
     return if !$wrksrc;
 
@@ -536,7 +539,7 @@ CPANPLUS::Dist::Slackware::PackageDescription - Collect information on a new Sla
 
 =head1 VERSION
 
-This document describes CPANPLUS::Dist::Slackware::PackageDescription version 1.027.
+This document describes CPANPLUS::Dist::Slackware::PackageDescription version 1.028.
 
 =head1 SYNOPSIS
 
@@ -737,7 +740,7 @@ through the web interface at L<http://rt.cpan.org/>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012-2018 Andreas Voegele
+Copyright 2012-2020 Andreas Voegele
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
